@@ -7,7 +7,7 @@ from ...utils.custom_exceptions import InvalidSourceChecker
 from ...utils.types.identifier import StrObjectId
 from .helpers import SourceHelpers
 from ...base_models import CompanyAssetModel
-from ....models.company.assets.ai_agents.chatty_ai_agent_config_for_automation import ChattyAIConfigForAutomation
+from ....models.company.assets.ai_agents_v2.chatty_ai_agent_config_for_automation import ChattyAIConfigForAutomation
 
 
 import logging
