@@ -1,7 +1,7 @@
 from __future__ import annotations
 from datetime import datetime
 from enum import StrEnum
-from typing import Optional, Self, Dict, Any
+from typing import Optional, Self, Dict, Any, TYPE_CHECKING
 
 from letschatty.models.utils.types.identifier import StrObjectId
 from letschatty.models.utils.types.serializer_type import SerializerType
@@ -10,8 +10,9 @@ from pydantic import BaseModel, ConfigDict, Field
 from zoneinfo import ZoneInfo
 from letschatty.models.company.assets.flow import FlowPreview
 from letschatty.models.company.assets.chat_assets import AssignedAssetToChat, ChatAssetType
-from letschatty.models.execution.execution import ExecutionContext
-import json
+
+if TYPE_CHECKING:
+    from letschatty.models.execution.execution import ExecutionContext
 
 class ExecutionResult(StrEnum):
     EXECUTED = "executed"
