@@ -10,6 +10,10 @@ from bson import ObjectId
 from ....utils import MessageType, Status, MessageSubtype
 from ..schema import ChattyContent, ChattyContext, ChattyReferral
 from letschatty.models.utils import StrObjectId
+import logging
+from letschatty.models.utils.custom_exceptions import ImpossibleError
+
+logger = logging.getLogger(__name__)
 
 class Message(BaseModel):
     created_at: datetime
@@ -143,7 +147,10 @@ class Message(BaseModel):
     @field_validator('created_at', 'updated_at')
     def ensure_utc(cls, v):
         if isinstance(v, datetime):
-            return v.replace(tzinfo=ZoneInfo("UTC")) if v.tzinfo is None else v.astimezone(ZoneInfo("UTC"))
+            v = v.replace(tzinfo=ZoneInfo("UTC")) if v.tzinfo is None else v.astimezone(ZoneInfo("UTC"))
+            if v > datetime.now(ZoneInfo("UTC")):
+                raise ImpossibleError(f"Message created at {v} is in the future")
+            return v
         raise ValueError('must be a datetime')
 
     def update_status(self, new_status: Status, status_datetime: datetime):
