@@ -3,6 +3,8 @@ from typing import Optional
 import logging
 import json
 from datetime import timedelta
+
+from letschatty.models.utils.definitions import Area
 logger = logging.getLogger("logger")
 
 class Context(BaseModel):
@@ -166,6 +168,12 @@ class HumanInterventionRequired(CustomException):
     def __init__(self, message="Human intervention required", status_code=400, **context_data):
         super().__init__(message, status_code=status_code, **context_data)
 
+class MaximumFollowUpsReached(CustomException):
+    def __init__(self, message="Maximum follow ups reached", status_code=400, area:Area = Area.WITH_AGENT, **context_data):
+        self.area = area
+        super().__init__(message, status_code=status_code, **context_data)
+
+
 class PostponeFollowUp(CustomException):
     def __init__(self, time_delta:timedelta,message="Follow up postponed", status_code=400, **context_data):
         self.time_delta = time_delta
