@@ -19,8 +19,8 @@ from typing import Dict, Any, Optional, List, TYPE_CHECKING
 from letschatty.models.execution.execution import ExecutionContext
 from letschatty.models.messages.meta_message_model.meta_status_json import ErrorDetail
 from ...models.company.assets.product import Product
-from ...models.company.assets.ai_agents.chatty_ai_agent import ChattyAIAgent
-from ...models.company.assets.ai_agents.chatty_ai_mode import ChattyAIMode
+from ...models.company.assets.ai_agents_v2.chatty_ai_agent import ChattyAIAgent
+from ...models.company.assets.ai_agents_v2.chatty_ai_mode import ChattyAIMode
 from ...models.company.assets.chat_assets import SaleAssignedToChat, AssignedAssetToChat, ChatAssetType, ContactPointAssignedToChat, ChattyAIAgentAssignedToChat
 from ...models.chat.scheduled_messages import ScheduledMessageStatus
 from ...models.utils.types.identifier import StrObjectId
