@@ -13,7 +13,7 @@ from ....models.company.assets.contact_point import ContactPoint
 from ....models.analytics.events.base import Event
 from ....models.company.company_chats_snapshot import CompanyChatsSnapshot
 from ....models.company.assets.users.agent_chats_snapshot import AgentChatsSnapshot
-from ....models.company.assets.ai_agents.chatty_ai_agent import ChattyAIAgent
+from ....models.company.assets.ai_agents_v2.chatty_ai_agent import ChattyAIAgent
 from zoneinfo import ZoneInfo
 from typing import List
 from ....models.chat.highlight import Highlight
@@ -466,9 +466,8 @@ class EventFactory:
             message=message if event_type != EventType.MESSAGE_STATUS_UPDATED else None,
             wamid=message.id,
             new_status = new_status,
-            is_first_response=ChatService.is_first_response(chat_with_assets.chat, message),
-            response_time_seconds=ChatService.get_response_time(chat_with_assets.chat, message)
-        )
+            webhook_for_agent_type=chat_with_assets.chatty_ai_agent.n8n_workspace_agent_type if chat_with_assets.chatty_ai_agent else None
+                    )
         event = MessageEvent(
             specversion=EventFactory.package_version(),
             type=event_type,
@@ -592,13 +591,11 @@ class EventFactory:
         events = []
 
         user_data = UserEventData(
-            company_phone_number_id=company_info.phone_number_id, #type: ignore
-            company_waba_id=company_info.waba_id_value,
             user_id=user.id,
             executor_type=executor_type,
             executor_id=executor_id,
             company_id=company_info.id,
-            new_status=user.status if event_type == EventType.USER_STATUS_UPDATED else None,
+            new_status=user.status if event_type == EventType.USER_STATUS_UPDATED else None, #type: ignore
             business_area_id=business_area_id,
             funnel_id=funnel_id
 
